@@ -103,12 +103,14 @@ def datetime_schema():
 
 
 def update_refs(schema: ExternalType, from_location: str, to_location: str):
-    """ Swap a referenced schema from one location to another """
+    """Swap a referenced schema from one location to another"""
     if isinstance(schema, dict):
-        schema = {k: update_refs(s, from_location, to_location) for k, s in schema.items()}
-        ref = schema.get('$ref')
+        schema = {
+            k: update_refs(s, from_location, to_location) for k, s in schema.items()
+        }
+        ref = schema.get("$ref")
         if ref == from_location:
-            schema['$ref'] = to_location
+            schema["$ref"] = to_location
     elif isinstance(schema, list):
         return [update_refs(s, from_location, to_location) for s in schema]
     return schema
